@@ -39,6 +39,7 @@ logger = logging.getLogger(__name__)
 COMPUTE_ENVIRONMENT_NAME_REGEX = re.compile(
     r"^[A-Za-z0-9][A-Za-z0-9_-]{1,126}[A-Za-z0-9]$"
 )
+JOB_NAME_REGEX = re.compile(r"^[A-Za-z0-9][A-Za-z0-9_-]{1,127}$")
 
 
 def datetime2int_milliseconds(date: datetime.datetime) -> int:
@@ -725,7 +726,7 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
                     )
                     date = unix_time_millis(date_obj)
                     logs.append({"timestamp": date, "message": line.strip()})
-                logs = sorted(logs, key=lambda l: l["timestamp"])
+                logs = sorted(logs, key=lambda log: log["timestamp"])
 
                 # Send to cloudwatch
                 log_group = "/aws/batch/job"
@@ -1523,6 +1524,9 @@ class BatchBackend(BaseBackend):
         """
         Parameters RetryStrategy and Parameters are not yet implemented.
         """
+        if JOB_NAME_REGEX.match(job_name) is None:
+            raise ClientException("Job name should match valid pattern")
+
         # Look for job definition
         job_def = self.get_job_definition(job_def_id)
         if job_def is None:
@@ -1599,11 +1603,11 @@ class BatchBackend(BaseBackend):
     def cancel_job(self, job_id: str, reason: str) -> None:
         if job_id == "":
             raise ClientException(
-                "'reason' is a required field (cannot be an empty string)"
+                "'jobId' is a required field (cannot be an empty string)"
             )
         if reason == "":
             raise ClientException(
-                "'jobId' is a required field (cannot be an empty string)"
+                "'reason' is a required field (cannot be an empty string)"
             )
 
         job = self.get_job_by_id(job_id)
@@ -1615,11 +1619,11 @@ class BatchBackend(BaseBackend):
     def terminate_job(self, job_id: str, reason: str) -> None:
         if job_id == "":
             raise ClientException(
-                "'reason' is a required field (cannot be a empty string)"
+                "'jobId' is a required field (cannot be a empty string)"
             )
         if reason == "":
             raise ClientException(
-                "'jobId' is a required field (cannot be a empty string)"
+                "'reason' is a required field (cannot be a empty string)"
             )
 
         job = self.get_job_by_id(job_id)
