@@ -1,4 +1,5 @@
 import json
+import re
 import yaml
 from typing import Any, Dict, Tuple, List, Optional, Union
 from urllib.parse import urlparse
@@ -124,6 +125,8 @@ class CloudFormationResponse(BaseResponse):
         template_url = self._get_param("TemplateURL")
         role_arn = self._get_param("RoleARN")
         enable_termination_protection = self._get_param("EnableTerminationProtection")
+        timeout_in_mins = self._get_param("TimeoutInMinutes")
+        stack_policy_body = self._get_param("StackPolicyBody")
         parameters_list = self._get_list_prefix("Parameters.member")
         tags = dict(
             (item["key"], item["value"])
@@ -150,6 +153,8 @@ class CloudFormationResponse(BaseResponse):
             tags=tags,
             role_arn=role_arn,
             enable_termination_protection=enable_termination_protection,
+            timeout_in_mins=timeout_in_mins,
+            stack_policy_body=stack_policy_body,
         )
         if self.request_json:
             return json.dumps(
@@ -270,37 +275,29 @@ class CloudFormationResponse(BaseResponse):
 
     def describe_stack_resource(self) -> str:
         stack_name = self._get_param("StackName")
-        stack = self.cloudformation_backend.get_stack(stack_name)
         logical_resource_id = self._get_param("LogicalResourceId")
-
-        resource = None
-        for stack_resource in stack.stack_resources:
-            if stack_resource.logical_resource_id == logical_resource_id:  # type: ignore[attr-defined]
-                resource = stack_resource
-                break
-
-        if not resource:
-            message = (
-                f"Resource {logical_resource_id} does not exist for stack {stack_name}"
-            )
-            raise ValidationError(stack_name, message)
+        stack, resource = self.cloudformation_backend.describe_stack_resource(
+            stack_name, logical_resource_id
+        )
 
         template = self.response_template(DESCRIBE_STACK_RESOURCE_RESPONSE_TEMPLATE)
         return template.render(stack=stack, resource=resource)
 
     def describe_stack_resources(self) -> str:
         stack_name = self._get_param("StackName")
-        stack = self.cloudformation_backend.get_stack(stack_name)
+        stack, resources = self.cloudformation_backend.describe_stack_resources(
+            stack_name
+        )
 
         template = self.response_template(DESCRIBE_STACK_RESOURCES_RESPONSE)
-        return template.render(stack=stack)
+        return template.render(stack=stack, resources=resources)
 
     def describe_stack_events(self) -> str:
         stack_name = self._get_param("StackName")
-        stack = self.cloudformation_backend.get_stack(stack_name)
+        events = self.cloudformation_backend.describe_stack_events(stack_name)
 
         template = self.response_template(DESCRIBE_STACK_EVENTS_RESPONSE)
-        return template.render(stack=stack)
+        return template.render(events=events)
 
     def list_change_sets(self) -> str:
         change_sets = self.cloudformation_backend.list_change_sets()
@@ -322,14 +319,14 @@ class CloudFormationResponse(BaseResponse):
 
     def get_template(self) -> str:
         name_or_stack_id = self.querystring.get("StackName")[0]  # type: ignore[index]
-        stack = self.cloudformation_backend.get_stack(name_or_stack_id)
+        stack_template = self.cloudformation_backend.get_template(name_or_stack_id)
 
         if self.request_json:
             return json.dumps(
                 {
                     "GetTemplateResponse": {
                         "GetTemplateResult": {
-                            "TemplateBody": stack.template,
+                            "TemplateBody": stack_template,
                             "ResponseMetadata": {
                                 "RequestId": "2d06e36c-ac1d-11e0-a958-f9382b6eb86bEXAMPLE"
                             },
@@ -339,7 +336,7 @@ class CloudFormationResponse(BaseResponse):
             )
         else:
             template = self.response_template(GET_TEMPLATE_RESPONSE_TEMPLATE)
-            return template.render(stack=stack)
+            return template.render(stack_template=stack_template)
 
     def get_template_summary(self) -> str:
         stack_name = self._get_param("StackName")
@@ -462,9 +459,17 @@ class CloudFormationResponse(BaseResponse):
 
     def create_stack_set(self) -> str:
         stackset_name = self._get_param("StackSetName")
+        if not re.match(r"^[a-zA-Z][-a-zA-Z0-9]*$", stackset_name):
+            raise ValidationError(
+                message=f"1 validation error detected: Value '{stackset_name}' at 'stackSetName' failed to satisfy constraint: Member must satisfy regular expression pattern: [a-zA-Z][-a-zA-Z0-9]*"
+            )
         stack_body = self._get_param("TemplateBody")
         template_url = self._get_param("TemplateURL")
+        permission_model = self._get_param("PermissionModel")
         parameters_list = self._get_list_prefix("Parameters.member")
+        admin_role = self._get_param("AdministrationRoleARN")
+        exec_role = self._get_param("ExecutionRoleName")
+        description = self._get_param("Description")
         tags = dict(
             (item["key"], item["value"])
             for item in self._get_list_prefix("Tags.member")
@@ -481,7 +486,14 @@ class CloudFormationResponse(BaseResponse):
             stack_body = self._get_stack_from_s3_url(template_url)
 
         stackset = self.cloudformation_backend.create_stack_set(
-            name=stackset_name, template=stack_body, parameters=parameters, tags=tags
+            name=stackset_name,
+            template=stack_body,
+            parameters=parameters,
+            tags=tags,
+            permission_model=permission_model,
+            admin_role=admin_role,
+            exec_role=exec_role,
+            description=description,
         )
         if self.request_json:
             return json.dumps(
@@ -500,11 +512,25 @@ class CloudFormationResponse(BaseResponse):
         accounts = self._get_multi_param("Accounts.member")
         regions = self._get_multi_param("Regions.member")
         parameters = self._get_multi_param("ParameterOverrides.member")
-        self.cloudformation_backend.create_stack_instances(
-            stackset_name, accounts, regions, parameters
+        deployment_targets = self._get_params().get("DeploymentTargets")
+        if deployment_targets and "OrganizationalUnitIds" in deployment_targets:
+            for ou_id in deployment_targets.get("OrganizationalUnitIds", []):
+                if not re.match(
+                    r"^(ou-[a-z0-9]{4,32}-[a-z0-9]{8,32}|r-[a-z0-9]{4,32})$", ou_id
+                ):
+                    raise ValidationError(
+                        message=f"1 validation error detected: Value '[{ou_id}]' at 'deploymentTargets.organizationalUnitIds' failed to satisfy constraint: Member must satisfy constraint: [Member must have length less than or equal to 68, Member must have length greater than or equal to 6, Member must satisfy regular expression pattern: ^(ou-[a-z0-9]{{4,32}}-[a-z0-9]{{8,32}}|r-[a-z0-9]{{4,32}})$]"
+                    )
+
+        operation_id = self.cloudformation_backend.create_stack_instances(
+            stackset_name,
+            accounts,
+            regions,
+            parameters,
+            deployment_targets=deployment_targets,
         )
         template = self.response_template(CREATE_STACK_INSTANCES_TEMPLATE)
-        return template.render()
+        return template.render(operation_id=operation_id)
 
     def delete_stack_set(self) -> str:
         stackset_name = self._get_param("StackSetName")
@@ -525,7 +551,7 @@ class CloudFormationResponse(BaseResponse):
 
     def describe_stack_set(self) -> str:
         stackset_name = self._get_param("StackSetName")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
+        stackset = self.cloudformation_backend.describe_stack_set(stackset_name)
 
         if not stackset.admin_role:
             stackset.admin_role = f"arn:aws:iam::{self.current_account}:role/AWSCloudFormationStackSetAdministrationRole"
@@ -540,51 +566,56 @@ class CloudFormationResponse(BaseResponse):
         account = self._get_param("StackInstanceAccount")
         region = self._get_param("StackInstanceRegion")
 
-        instance = self.cloudformation_backend.get_stack_set(
-            stackset_name
-        ).instances.get_instance(account, region)
+        instance = self.cloudformation_backend.describe_stack_instance(
+            stackset_name, account, region
+        )
         template = self.response_template(DESCRIBE_STACK_INSTANCE_TEMPLATE)
         rendered = template.render(instance=instance)
         return rendered
 
     def list_stack_sets(self) -> str:
-        stacksets = self.cloudformation_backend.stacksets
+        stacksets = self.cloudformation_backend.list_stack_sets()
         template = self.response_template(LIST_STACK_SETS_TEMPLATE)
         return template.render(stacksets=stacksets)
 
     def list_stack_instances(self) -> str:
         stackset_name = self._get_param("StackSetName")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
+        instances = self.cloudformation_backend.list_stack_instances(stackset_name)
         template = self.response_template(LIST_STACK_INSTANCES_TEMPLATE)
-        return template.render(stackset=stackset)
+        return template.render(instances=instances)
 
     def list_stack_set_operations(self) -> str:
         stackset_name = self._get_param("StackSetName")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
+        operations = self.cloudformation_backend.list_stack_set_operations(
+            stackset_name
+        )
         template = self.response_template(LIST_STACK_SET_OPERATIONS_RESPONSE_TEMPLATE)
-        return template.render(stackset=stackset)
+        return template.render(operations=operations)
 
     def stop_stack_set_operation(self) -> str:
         stackset_name = self._get_param("StackSetName")
         operation_id = self._get_param("OperationId")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
-        stackset.update_operation(operation_id, "STOPPED")
+        self.cloudformation_backend.stop_stack_set_operation(
+            stackset_name, operation_id
+        )
         template = self.response_template(STOP_STACK_SET_OPERATION_RESPONSE_TEMPLATE)
         return template.render()
 
     def describe_stack_set_operation(self) -> str:
         stackset_name = self._get_param("StackSetName")
         operation_id = self._get_param("OperationId")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
-        operation = stackset.get_operation(operation_id)
+        stackset, operation = self.cloudformation_backend.describe_stack_set_operation(
+            stackset_name, operation_id
+        )
         template = self.response_template(DESCRIBE_STACKSET_OPERATION_RESPONSE_TEMPLATE)
         return template.render(stackset=stackset, operation=operation)
 
     def list_stack_set_operation_results(self) -> str:
         stackset_name = self._get_param("StackSetName")
         operation_id = self._get_param("OperationId")
-        stackset = self.cloudformation_backend.get_stack_set(stackset_name)
-        operation = stackset.get_operation(operation_id)
+        operation = self.cloudformation_backend.list_stack_set_operation_results(
+            stackset_name, operation_id
+        )
         template = self.response_template(
             LIST_STACK_SET_OPERATION_RESULTS_RESPONSE_TEMPLATE
         )
@@ -790,7 +821,7 @@ DESCRIBE_STACKS_TEMPLATE = """<DescribeStacksResponse>
         <StackName>{{ stack.name }}</StackName>
         <StackId>{{ stack.stack_id }}</StackId>
         {% if stack.change_set_id %}
-        <ChangeSetId>{{ stack.change_set_id }}</ChangeSetId>
+        <ChangeSetId>{{ stack.change_set_id }}</stack.timeout_in_minsChangeSetId>
         {% endif %}
         <Description><![CDATA[{{ stack.description }}]]></Description>
         <CreationTime>{{ stack.creation_time_iso_8601 }}</CreationTime>
@@ -837,6 +868,9 @@ DESCRIBE_STACKS_TEMPLATE = """<DescribeStacksResponse>
           {% endfor %}
         </Tags>
         <EnableTerminationProtection>{{ stack.enable_termination_protection }}</EnableTerminationProtection>
+        {% if stack.timeout_in_mins %}
+        <TimeoutInMinutes>{{ stack.timeout_in_mins }}</TimeoutInMinutes>
+        {% endif %}
       </member>
       {% endfor %}
     </Stacks>
@@ -863,7 +897,7 @@ DESCRIBE_STACK_RESOURCE_RESPONSE_TEMPLATE = """<DescribeStackResourceResponse>
 DESCRIBE_STACK_RESOURCES_RESPONSE = """<DescribeStackResourcesResponse>
     <DescribeStackResourcesResult>
       <StackResources>
-        {% for resource in stack.stack_resources %}
+        {% for resource in resources %}
         <member>
           <StackId>{{ stack.stack_id }}</StackId>
           <StackName>{{ stack.name }}</StackName>
@@ -881,7 +915,7 @@ DESCRIBE_STACK_RESOURCES_RESPONSE = """<DescribeStackResourcesResponse>
 DESCRIBE_STACK_EVENTS_RESPONSE = """<DescribeStackEventsResponse xmlns="http://cloudformation.amazonaws.com/doc/2010-05-15/">
   <DescribeStackEventsResult>
     <StackEvents>
-      {% for event in stack.events[::-1] %}
+      {% for event in events[::-1] %}
       <member>
         <Timestamp>{{ event.timestamp.strftime('%Y-%m-%dT%H:%M:%S.%fZ') }}</Timestamp>
         <ResourceStatus>{{ event.resource_status }}</ResourceStatus>
@@ -959,7 +993,7 @@ LIST_STACKS_RESOURCES_RESPONSE = """<ListStackResourcesResponse>
 
 GET_TEMPLATE_RESPONSE_TEMPLATE = """<GetTemplateResponse>
   <GetTemplateResult>
-    <TemplateBody>{{ stack.template }}</TemplateBody>
+    <TemplateBody>{{ stack_template }}</TemplateBody>
   </GetTemplateResult>
   <ResponseMetadata>
     <RequestId>b9b4b068-3a41-11e5-94eb-example</RequestId>
@@ -1030,6 +1064,10 @@ DESCRIBE_STACK_SET_RESPONSE_TEMPLATE = """<DescribeStackSetResponse xmlns="http:
           {% endfor %}
         </Tags>
       <Status>{{ stackset.status }}</Status>
+      <PermissionModel>{{ stackset.permission_model }}</PermissionModel>
+      {% if stackset.description %}
+      <Description>{{ stackset.description }}</Description>
+      {% endif %}
     </StackSet>
   </DescribeStackSetResult>
   <ResponseMetadata>
@@ -1046,7 +1084,7 @@ DELETE_STACK_SET_RESPONSE_TEMPLATE = """<DeleteStackSetResponse xmlns="http://in
 
 CREATE_STACK_INSTANCES_TEMPLATE = """<CreateStackInstancesResponse xmlns="http://internal.amazon.com/coral/com.amazonaws.maestro.service.v20160713/">
   <CreateStackInstancesResult>
-    <OperationId>1459ad6d-63cc-4c96-a73e-example</OperationId>
+    <OperationId>{{ operation_id }}</OperationId>
   </CreateStackInstancesResult>
   <ResponseMetadata>
     <RequestId>6b29f7e3-69be-4d32-b374-example</RequestId>
@@ -1057,13 +1095,13 @@ CREATE_STACK_INSTANCES_TEMPLATE = """<CreateStackInstancesResponse xmlns="http:/
 LIST_STACK_INSTANCES_TEMPLATE = """<ListStackInstancesResponse xmlns="http://internal.amazon.com/coral/com.amazonaws.maestro.service.v20160713/">
   <ListStackInstancesResult>
     <Summaries>
-    {% for instance in stackset.stack_instances %}
+    {% for instance in instances %}
       <member>
-        <StackId>{{ instance.StackId }}</StackId>
-        <StackSetId>{{ instance.StackSetId }}</StackSetId>
-        <Region>{{ instance.Region }}</Region>
-        <Account>{{ instance.Account }}</Account>
-        <Status>{{ instance.Status }}</Status>
+        <StackId>{{ instance["StackId"] }}</StackId>
+        <StackSetId>{{ instance["StackSetId"] }}</StackSetId>
+        <Region>{{ instance["Region"] }}</Region>
+        <Account>{{ instance["Account"] }}</Account>
+        <Status>{{ instance["Status"] }}</Status>
       </member>
     {% endfor %}
     </Summaries>
@@ -1087,16 +1125,16 @@ DELETE_STACK_INSTANCES_TEMPLATE = """<DeleteStackInstancesResponse xmlns="http:/
 DESCRIBE_STACK_INSTANCE_TEMPLATE = """<DescribeStackInstanceResponse xmlns="http://internal.amazon.com/coral/com.amazonaws.maestro.service.v20160713/">
   <DescribeStackInstanceResult>
     <StackInstance>
-      <StackId>{{ instance.StackId }}</StackId>
-      <StackSetId>{{ instance.StackSetId }}</StackSetId>
-    {% if instance.ParameterOverrides %}
+      <StackId>{{ instance["StackId"] }}</StackId>
+      <StackSetId>{{ instance["StackSetId"] }}</StackSetId>
+    {% if instance["ParameterOverrides"] %}
       <ParameterOverrides>
-      {% for override in instance.ParameterOverrides %}
+      {% for override in instance["ParameterOverrides"] %}
       {% if override['ParameterKey'] or override['ParameterValue'] %}
         <member>
-          <ParameterKey>{{ override.ParameterKey }}</ParameterKey>
+          <ParameterKey>{{ override["ParameterKey"] }}</ParameterKey>
           <UsePreviousValue>false</UsePreviousValue>
-          <ParameterValue>{{ override.ParameterValue }}</ParameterValue>
+          <ParameterValue>{{ override["ParameterValue"] }}</ParameterValue>
         </member>
       {% endif %}
       {% endfor %}
@@ -1104,9 +1142,9 @@ DESCRIBE_STACK_INSTANCE_TEMPLATE = """<DescribeStackInstanceResponse xmlns="http
     {% else %}
       <ParameterOverrides/>
     {% endif %}
-      <Region>{{ instance.Region }}</Region>
-      <Account>{{ instance.Account }}</Account>
-      <Status>{{ instance.Status }}</Status>
+      <Region>{{ instance["Region"] }}</Region>
+      <Account>{{ instance["Account"] }}</Account>
+      <Status>{{ instance["Status"] }}</Status>
     </StackInstance>
   </DescribeStackInstanceResult>
   <ResponseMetadata>
@@ -1118,11 +1156,11 @@ DESCRIBE_STACK_INSTANCE_TEMPLATE = """<DescribeStackInstanceResponse xmlns="http
 LIST_STACK_SETS_TEMPLATE = """<ListStackSetsResponse xmlns="http://internal.amazon.com/coral/com.amazonaws.maestro.service.v20160713/">
   <ListStackSetsResult>
     <Summaries>
-    {% for key, value in stacksets.items() %}
+    {% for stackset in stacksets %}
       <member>
-        <StackSetName>{{ value.name }}</StackSetName>
-        <StackSetId>{{ value.id }}</StackSetId>
-        <Status>{{ value.status }}</Status>
+        <StackSetName>{{ stackset.name }}</StackSetName>
+        <StackSetId>{{ stackset.id }}</StackSetId>
+        <Status>{{ stackset.status }}</Status>
       </member>
     {% endfor %}
     </Summaries>
@@ -1156,7 +1194,7 @@ UPDATE_STACK_SET_RESPONSE_TEMPLATE = """<UpdateStackSetResponse xmlns="http://in
 LIST_STACK_SET_OPERATIONS_RESPONSE_TEMPLATE = """<ListStackSetOperationsResponse xmlns="http://internal.amazon.com/coral/com.amazonaws.maestro.service.v20160713/">
   <ListStackSetOperationsResult>
     <Summaries>
-    {% for operation in stackset.operations %}
+    {% for operation in operations %}
       <member>
         <CreationTimestamp>{{ operation.CreationTimestamp }}</CreationTimestamp>
         <OperationId>{{ operation.OperationId }}</OperationId>
