@@ -1,8 +1,7 @@
 import json
 
 from datetime import datetime
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
 
 from .exceptions import (
     InvalidResourceStateFault,
