@@ -64,19 +64,15 @@ class NestableExpressionParserMixin(object):
         Returns:
 
         """
+        pos = self.token_pos
+        fc = factory_class.__class__.__name__
         logger.debug(
-            "Move token pos {pos} to continue parsing with specific factory class {fc}".format(
-                pos=self.token_pos, fc=factory_class.__class__.__name__
-            )
+            f"Move token pos {pos} to continue parsing with specific factory class {fc}"
         )
         # noinspection PyProtectedMember
         ast, token_pos = factory_class(**self._initializer_args())._parse_with_pos()
         self.target_clauses.append(ast)
-        logger.debug(
-            "Continue where previous parsing ended {token_pos}".format(
-                token_pos=token_pos
-            )
-        )
+        logger.debug(f"Continue where previous parsing ended {token_pos}")
         self.token_pos = token_pos
 
     @abstractmethod
@@ -118,9 +114,8 @@ class NestableExpressionParserMixin(object):
         Returns:
             moto.dynamodb.ast_nodes.Node: Node of an AST representing the Expression as produced by the factory.
         """
-        assert len(self.target_clauses) > 0, "No nodes for {cn}".format(
-            cn=self.__class__.__name__
-        )
+        cn = self.__class__.__name__
+        assert len(self.target_clauses) > 0, f"No nodes for {cn}"
         target_node = self._nestable_class()(children=[self.target_clauses.pop()])
         while len(self.target_clauses) > 0:
             target_node = self._nestable_class()(
@@ -358,11 +353,7 @@ class NestableBinExpressionParser(ExpressionParser):
             **self._initializer_args()
         )._parse_with_pos()
         self.target_nodes.append(ast)
-        logger.debug(
-            "Continue where previous parsing ended {token_pos}".format(
-                token_pos=self.token_pos
-            )
-        )
+        logger.debug(f"Continue where previous parsing ended {self.token_pos}")
 
     def _parse(self):
         self._parse_target_clause(self._operand_factory_class())
@@ -525,11 +516,8 @@ class UpdateExpressionActionsParser(ExpressionParser, NestableExpressionParserMi
 
     @classmethod
     def _is_possible_start(cls, token):
-        raise RuntimeError(
-            "{class_name} cannot be identified by the next token.".format(
-                class_name=cls._nestable_class().__name__
-            )
-        )
+        cn = cls._nestable_class().__name__
+        raise RuntimeError(f"{cn} cannot be identified by the next token.")
 
     @classmethod
     @abstractmethod
@@ -562,12 +550,9 @@ class UpdateExpressionActionsParser(ExpressionParser, NestableExpressionParserMi
                 break
 
         if len(self.target_clauses) == 0:
-            logger.debug(
-                "Didn't encounter a single {nc} in {nepc}.".format(
-                    nc=self._nestable_class().__name__,
-                    nepc=self._nested_expression_parser_class().__name__,
-                )
-            )
+            nc = self._nestable_class().__name__
+            nepc = self._nested_expression_parser_class().__name__
+            logger.debug(f"Didn't encounter a single {nc} in {nepc}.")
             self.raise_unexpected_token()
 
         return self._create_node()
