@@ -1,4 +1,5 @@
 from moto.core.responses import BaseResponse
+from ..exceptions import EmptyTagSpecError
 from ..utils import convert_tag_spec
 
 
@@ -12,5 +13,10 @@ class EC2BaseResponse(BaseResponse):
     def _parse_tag_specification(self):
         # [{"ResourceType": _type, "Tag": [{"Key": k, "Value": v}, ..]}]
         tag_spec_set = self._get_multi_param("TagSpecification")
+        # If we do not pass any Tags, this method will convert this to [_type] instead
+        if isinstance(tag_spec_set, list) and any(
+            [isinstance(spec, str) for spec in tag_spec_set]
+        ):
+            raise EmptyTagSpecError
         # {_type: {k: v, ..}}
         return convert_tag_spec(tag_spec_set)
