@@ -61,6 +61,7 @@ class ElasticBlockStore(EC2BaseResponse):
         volume_tags = tags.get("volume", {})
         encrypted = self._get_bool_param("Encrypted", if_none=False)
         kms_key_id = self._get_param("KmsKeyId")
+        iops = self._get_param("Iops")
         if self.is_not_dryrun("CreateVolume"):
             volume = self.ec2_backend.create_volume(
                 size=size,
@@ -69,11 +70,33 @@ class ElasticBlockStore(EC2BaseResponse):
                 encrypted=encrypted,
                 kms_key_id=kms_key_id,
                 volume_type=volume_type,
+                iops=iops,
             )
             volume.add_tags(volume_tags)
             template = self.response_template(CREATE_VOLUME_RESPONSE)
             return template.render(volume=volume)
 
+    def modify_volume(self):
+        volume_id = self._get_param("VolumeId")
+        target_size = self._get_param("Size")
+        target_volume_type = self._get_param("VolumeType")
+
+        if self.is_not_dryrun("ModifyVolume"):
+            volume = self.ec2_backend.modify_volume(
+                volume_id, target_size, target_volume_type
+            )
+            template = self.response_template(MODIFY_VOLUME_RESPONSE)
+            return template.render(volume=volume)
+
+    def describe_volumes_modifications(self):
+        filters = self._filters_from_querystring()
+        volume_ids = self._get_multi_param("VolumeId")
+        modifications = self.ec2_backend.describe_volumes_modifications(
+            volume_ids=volume_ids, filters=filters
+        )
+        template = self.response_template(DESCRIBE_VOLUMES_MODIFICATIONS_RESPONSE)
+        return template.render(modifications=modifications)
+
     def delete_snapshot(self):
         snapshot_id = self._get_param("SnapshotId")
         if self.is_not_dryrun("DeleteSnapshot"):
@@ -188,7 +211,7 @@ CREATE_VOLUME_RESPONSE = """<CreateVolumeResponse xmlns="http://ec2.amazonaws.co
   {% endif %}
   <availabilityZone>{{ volume.zone.name }}</availabilityZone>
   <status>creating</status>
-  <createTime>{{ volume.create_time}}</createTime>
+  <createTime>{{ volume.create_time }}</createTime>
   {% if volume.get_tags() %}
     <tagSet>
       {% for tag in volume.get_tags() %}
@@ -202,6 +225,9 @@ CREATE_VOLUME_RESPONSE = """<CreateVolumeResponse xmlns="http://ec2.amazonaws.co
     </tagSet>
   {% endif %}
   <volumeType>{{ volume.volume_type }}</volumeType>
+  {% if volume.iops %}
+    <iops>{{ volume.iops }}</iops>
+  {% endif %}
 </CreateVolumeResponse>"""
 
 DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
@@ -222,7 +248,7 @@ DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazon
              {% endif %}
              <availabilityZone>{{ volume.zone.name }}</availabilityZone>
              <status>{{ volume.status }}</status>
-             <createTime>{{ volume.create_time}}</createTime>
+             <createTime>{{ volume.create_time }}</createTime>
              <attachmentSet>
                 {% if volume.attachment %}
                     <item>
@@ -248,6 +274,9 @@ DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazon
                </tagSet>
              {% endif %}
              <volumeType>{{ volume.volume_type }}</volumeType>
+             {% if volume.iops %}
+               <iops>{{ volume.iops }}</iops>
+             {% endif %}
           </item>
       {% endfor %}
    </volumeSet>
@@ -402,3 +431,40 @@ MODIFY_SNAPSHOT_ATTRIBUTE_RESPONSE = """
     <return>true</return>
 </ModifySnapshotAttributeResponse>
 """
+
+MODIFY_VOLUME_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
+<ModifyVolumeResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+    <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
+    <volumeModification>
+        {% set volume_modification = volume.modifications[-1] %}
+        <modificationState>modifying</modificationState>
+        <originalSize>{{ volume_modification.original_size }}</originalSize>
+        <originalVolumeType>{{ volume_modification.original_volume_type }}</originalVolumeType>
+        <progress>0</progress>
+        <startTime>{{ volume_modification.start_time }}</startTime>
+        <targetSize>{{ volume_modification.target_size }}</targetSize>
+        <targetVolumeType>{{ volume_modification.target_volume_type }}</targetVolumeType>
+        <volumeId>{{ volume.id }}</volumeId>
+    </volumeModification>
+</ModifyVolumeResponse>"""
+
+DESCRIBE_VOLUMES_MODIFICATIONS_RESPONSE = """
+<?xml version="1.0" encoding="UTF-8"?>
+<DescribeVolumesModificationsResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+    <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
+    <volumeModificationSet>
+      {% for modification in modifications %}
+        <item>
+            <endTime>{{ modification.end_time }}</endTime>
+            <modificationState>completed</modificationState>
+            <originalSize>{{ modification.original_size }}</originalSize>
+            <originalVolumeType>{{ modification.original_volume_type }}</originalVolumeType>
+            <progress>100</progress>
+            <startTime>{{ modification.start_time }}</startTime>
+            <targetSize>{{ modification.target_size }}</targetSize>
+            <targetVolumeType>{{ modification.target_volume_type }}</targetVolumeType>
+            <volumeId>{{ modification.volume.id }}</volumeId>
+        </item>
+      {% endfor %}
+    </volumeModificationSet>
+</DescribeVolumesModificationsResponse>"""
