@@ -1,8 +1,7 @@
 import re
 from copy import copy
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any
-import pytz
 
 from moto import settings
 from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
@@ -422,7 +421,7 @@ class Service(BaseObject, CloudFormationModel):
         if self.deployment_controller["type"] == "ECS":
             self.deployments = [
                 {
-                    "createdAt": datetime.now(pytz.utc),
+                    "createdAt": datetime.now(timezone.utc),
                     "desiredCount": self.desired_count,
                     "id": f"ecs-svc/{mock_random.randint(0, 32**12)}",
                     "launchType": self.launch_type,
@@ -430,7 +429,7 @@ class Service(BaseObject, CloudFormationModel):
                     "runningCount": 0,
                     "status": "PRIMARY",
                     "taskDefinition": self.task_definition,
-                    "updatedAt": datetime.now(pytz.utc),
+                    "updatedAt": datetime.now(timezone.utc),
                 }
             ]
         else:
@@ -651,7 +650,7 @@ class ContainerInstance(BaseObject):
             if ec2_instance.platform == "windows"
             else "linux",  # options are windows and linux, linux is default
         }
-        self.registered_at = datetime.now(pytz.utc)
+        self.registered_at = datetime.now(timezone.utc)
         self.region_name = region_name
         self.id = str(mock_random.uuid4())
         self.cluster_name = cluster_name
@@ -748,9 +747,9 @@ class TaskSet(BaseObject):
         self.client_token = client_token or ""
         self.tags = tags or []
         self.stabilityStatus = "STEADY_STATE"
-        self.createdAt = datetime.now(pytz.utc)
-        self.updatedAt = datetime.now(pytz.utc)
-        self.stabilityStatusAt = datetime.now(pytz.utc)
+        self.createdAt = datetime.now(timezone.utc)
+        self.updatedAt = datetime.now(timezone.utc)
+        self.stabilityStatusAt = datetime.now(timezone.utc)
         self.id = f"ecs-svc/{mock_random.randint(0, 32**12)}"
         self.service_arn = ""
         self.cluster_arn = ""
