@@ -1,4 +1,3 @@
-from moto.core import get_account_id
 from moto.core.responses import BaseResponse
 from .models import elastictranscoder_backends
 import json
@@ -6,11 +5,12 @@ import re
 
 
 class ElasticTranscoderResponse(BaseResponse):
-    SERVICE_NAME = "elastictranscoder"
+    def __init__(self):
+        super().__init__(service_name="elastictranscoder")
 
     @property
     def elastictranscoder_backend(self):
-        return elastictranscoder_backends[self.region]
+        return elastictranscoder_backends[self.current_account][self.region]
 
     def pipelines(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
@@ -40,7 +40,7 @@ class ElasticTranscoderResponse(BaseResponse):
         if not role:
             return self.err("Role cannot be blank")
         if not re.match("^arn:aws:iam::[0-9]+:role/.+", role):
-            return self.err("Role ARN is invalid: {}".format(role))
+            return self.err(f"Role ARN is invalid: {role}")
         if not output_bucket and not content_config:
             return self.err(
                 "[OutputBucket and ContentConfig:Bucket are not allowed to both be null.]"
@@ -75,17 +75,13 @@ class ElasticTranscoderResponse(BaseResponse):
     def validate_pipeline_id(self, pipeline_id):
         r = "^\\d{13}-\\w{6}$"
         if not re.match(r, pipeline_id):
-            msg = "1 validation error detected: Value '{}' at 'id' failed to satisfy constraint: Member must satisfy regular expression pattern: {}".format(
-                pipeline_id, r
-            )
+            msg = f"1 validation error detected: Value '{pipeline_id}' at 'id' failed to satisfy constraint: Member must satisfy regular expression pattern: {r}"
             return self.err(msg)
         try:
             self.elastictranscoder_backend.read_pipeline(pipeline_id)
             return None
         except KeyError:
-            msg = "The specified pipeline was not found: account={}, pipelineId={}.".format(
-                get_account_id(), pipeline_id
-            )
+            msg = f"The specified pipeline was not found: account={self.current_account}, pipelineId={pipeline_id}."
             return (
                 404,
                 {"status": 404, "x-amzn-ErrorType": "ResourceNotFoundException"},
