@@ -1,5 +1,4 @@
 import datetime
-import pytz
 from collections import OrderedDict
 from typing import List, Iterable
 
@@ -14,6 +13,7 @@ from .exceptions import (
     EmptyListenersError,
     InvalidSecurityGroupError,
     LoadBalancerNotFoundError,
+    NoActiveLoadBalancerFoundError,
     PolicyNotFoundError,
     TooManyTagsError,
     CertificateNotFoundException,
@@ -74,7 +74,7 @@ class FakeLoadBalancer(CloudFormationModel):
         self.zones = zones
         self.listeners = []
         self.backends = []
-        self.created_time = datetime.datetime.now(pytz.utc)
+        self.created_time = datetime.datetime.now(datetime.timezone.utc)
         self.scheme = scheme or "internet-facing"
         self.attributes = FakeLoadBalancer.get_default_attributes()
         self.policies = []
@@ -372,8 +372,11 @@ class ELBBackend(BaseBackend):
         return policies
 
     def describe_instance_health(self, lb_name, instances):
+        elb = self.get_load_balancer(lb_name)
+        if elb is None:
+            raise NoActiveLoadBalancerFoundError(name=lb_name)
         provided_ids = [i["InstanceId"] for i in instances]
-        registered_ids = self.get_load_balancer(lb_name).instance_ids
+        registered_ids = elb.instance_ids
         ec2_backend = ec2_backends[self.account_id][self.region_name]
         if len(provided_ids) == 0:
             provided_ids = registered_ids
