@@ -8,10 +8,13 @@ from .models import firehose_backends
 class FirehoseResponse(BaseResponse):
     """Handler for Firehose requests and responses."""
 
+    def __init__(self):
+        super().__init__(service_name="firehose")
+
     @property
     def firehose_backend(self):
         """Return backend instance specific to this region."""
-        return firehose_backends[self.region]
+        return firehose_backends[self.current_account][self.region]
 
     def create_delivery_stream(self):
         """Prepare arguments and respond to CreateDeliveryStream request."""
