@@ -5,4 +5,4 @@ class NotFoundException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(NotFoundException, self).__init__("NotFoundException", message)
+        super().__init__("NotFoundException", message)
