@@ -17,6 +17,8 @@ url_paths = {
     "{0}/v1/flows/(?P<flowarn>[^/.]+)/source/(?P<sourcearn>[^/.]+)": response.dispatch,
     "{0}/v1/flows/(?P<flowarn>[^/.]+)/outputs": response.dispatch,
     "{0}/v1/flows/(?P<flowarn>[^/.]+)/outputs/(?P<outputarn>[^/.]+)": response.dispatch,
+    "{0}/v1/flows/(?P<flowarn>[^/.]+)/entitlements": response.dispatch,
+    "{0}/v1/flows/(?P<flowarn>[^/.]+)/entitlements/(?P<entitlementarn>[^/.]+)": response.dispatch,
     "{0}/v1/flows/start/(?P<flowarn>[^/.]+)": response.dispatch,
     "{0}/v1/flows/stop/(?P<flowarn>[^/.]+)": response.dispatch,
     "{0}/tags/(?P<resourcearn>[^/.]+)": response.dispatch,
