@@ -162,3 +162,23 @@ class NoSuchDelegationSet(Route53ClientError):
     def __init__(self, delegation_set_id):
         super().__init__("NoSuchDelegationSet", delegation_set_id)
         self.content_type = "text/xml"
+
+
+class DnsNameInvalidForZone(Route53ClientError):
+    code = 400
+
+    def __init__(self, name, zone_name):
+        error_msg = (
+            f"""RRSet with DNS name {name} is not permitted in zone {zone_name}"""
+        )
+        super().__init__("InvalidChangeBatch", error_msg)
+
+
+class ChangeSetAlreadyExists(Route53ClientError):
+    code = 400
+
+    def __init__(self, action: str, name: str, _type: str):
+        super().__init__(
+            "InvalidChangeBatch",
+            f"Tried to {action.lower()} resource record set [name='{name}', type='{_type}'] but it already exists",
+        )
