@@ -265,9 +265,7 @@ class SecretsManagerBackend(BaseBackend):
         if not secret_version:
             raise ResourceNotFoundException(
                 "An error occurred (ResourceNotFoundException) when calling the GetSecretValue operation: Secrets "
-                "Manager can't find the specified secret value for VersionId: {}".format(
-                    version_id
-                )
+                f"Manager can't find the specified secret value for VersionId: {version_id}"
             )
 
         response_data = {
@@ -553,9 +551,7 @@ class SecretsManagerBackend(BaseBackend):
             try:
                 func = lambda_backend.get_function(secret.rotation_lambda_arn)
             except Exception:
-                msg = "Resource not found for ARN '{}'.".format(
-                    secret.rotation_lambda_arn
-                )
+                msg = f"Resource not found for ARN '{secret.rotation_lambda_arn}'."
                 raise ResourceNotFoundException(msg)
 
             for step in ["create", "set", "test", "finish"]:
@@ -594,11 +590,9 @@ class SecretsManagerBackend(BaseBackend):
         # password size must have value less than or equal to 4096
         if password_length > 4096:
             raise ClientError(
-                "ClientError: An error occurred (ValidationException) \
-                when calling the GetRandomPassword operation: 1 validation error detected: Value '{}' at 'passwordLength' \
-                failed to satisfy constraint: Member must have value less than or equal to 4096".format(
-                    password_length
-                )
+                f"ClientError: An error occurred (ValidationException) \
+                when calling the GetRandomPassword operation: 1 validation error detected: Value '{password_length}' at 'passwordLength' \
+                failed to satisfy constraint: Member must have value less than or equal to 4096"
             )
         if password_length < 4:
             raise InvalidParameterException(
@@ -772,14 +766,13 @@ class SecretsManagerBackend(BaseBackend):
         if remove_from_version_id:
             if remove_from_version_id not in secret.versions:
                 raise InvalidParameterException(
-                    "Not a valid version: %s" % remove_from_version_id
+                    f"Not a valid version: {remove_from_version_id}"
                 )
 
             stages = secret.versions[remove_from_version_id]["version_stages"]
             if version_stage not in stages:
                 raise InvalidParameterException(
-                    "Version stage %s not found in version %s"
-                    % (version_stage, remove_from_version_id)
+                    f"Version stage {version_stage} not found in version {remove_from_version_id}"
                 )
 
             stages.remove(version_stage)
@@ -787,7 +780,7 @@ class SecretsManagerBackend(BaseBackend):
         if move_to_version_id:
             if move_to_version_id not in secret.versions:
                 raise InvalidParameterException(
-                    "Not a valid version: %s" % move_to_version_id
+                    f"Not a valid version: {move_to_version_id}"
                 )
 
             stages = secret.versions[move_to_version_id]["version_stages"]
