@@ -1,6 +1,5 @@
-import random
 import string
-
+from moto.moto_api._internal import mock_random as random
 from .exceptions import MessageAttributesInvalid
 
 
@@ -15,7 +14,7 @@ def extract_input_message_attributes(querystring):
     index = 1
     while True:
         # Loop through looking for message attributes
-        name_key = "MessageAttributeName.{0}".format(index)
+        name_key = f"MessageAttributeName.{index}"
         name = querystring.get(name_key)
         if not name:
             # Found all attributes
@@ -32,19 +31,17 @@ def parse_message_attributes(
     index = 1
     while True:
         # Loop through looking for message attributes
-        name_key = base + "{0}.{1}.Name".format(key, index)
+        name_key = base + f"{key}.{index}.Name"
         name = querystring.get(name_key)
         if not name:
             # Found all attributes
             break
 
-        data_type_key = base + "{0}.{1}.{2}DataType".format(key, index, value_namespace)
+        data_type_key = base + f"{key}.{index}.{value_namespace}DataType"
         data_type = querystring.get(data_type_key)
         if not data_type:
             raise MessageAttributesInvalid(
-                "The message attribute '{0}' must contain non-empty message attribute value.".format(
-                    name[0]
-                )
+                f"The message attribute '{name[0]}' must contain non-empty message attribute value."
             )
 
         data_type_parts = data_type[0].split(".")
@@ -54,24 +51,18 @@ def parse_message_attributes(
             "Number",
         ]:
             raise MessageAttributesInvalid(
-                "The message attribute '{0}' has an invalid message attribute type, the set of supported type prefixes is Binary, Number, and String.".format(
-                    name[0]
-                )
+                f"The message attribute '{name[0]}' has an invalid message attribute type, the set of supported type prefixes is Binary, Number, and String."
             )
 
         type_prefix = "String"
         if data_type_parts[0] == "Binary":
             type_prefix = "Binary"
 
-        value_key = base + "{0}.{1}.{2}{3}Value".format(
-            key, index, value_namespace, type_prefix
-        )
+        value_key = base + f"{key}.{index}.{value_namespace}{type_prefix}Value"
         value = querystring.get(value_key)
         if not value:
             raise MessageAttributesInvalid(
-                "The message attribute '{0}' must contain non-empty message attribute value for message attribute type '{1}'.".format(
-                    name[0], data_type[0]
-                )
+                f"The message attribute '{name[0]}' must contain non-empty message attribute value for message attribute type '{data_type[0]}'."
             )
 
         message_attributes[name[0]] = {
