@@ -1,11 +1,11 @@
 import datetime
 import re
 from typing import Dict
-from moto.core import BaseBackend, BaseModel
+from moto.core import BaseBackend, BackendDict, BaseModel
 
 from .utils import make_arn_for_wacl
 from .exceptions import WAFV2DuplicateItemException, WAFNonexistentItemException
-from moto.core.utils import iso_8601_datetime_with_milliseconds, BackendDict
+from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.moto_api._internal import mock_random
 from moto.utilities.tagging_service import TaggingService
 from collections import OrderedDict
@@ -81,17 +81,17 @@ class WAFV2Backend(BaseBackend):
             raise WAFNonexistentItemException
         stage = self._find_apigw_stage(resource_arn)
         if stage:
-            stage["webAclArn"] = web_acl_arn
+            stage.web_acl_arn = web_acl_arn
 
     def disassociate_web_acl(self, resource_arn):
         stage = self._find_apigw_stage(resource_arn)
         if stage:
-            stage.pop("webAclArn", None)
+            stage.web_acl_arn = None
 
     def get_web_acl_for_resource(self, resource_arn):
         stage = self._find_apigw_stage(resource_arn)
-        if stage and stage.get("webAclArn"):
-            wacl_arn = stage.get("webAclArn")
+        if stage and stage.web_acl_arn is not None:
+            wacl_arn = stage.web_acl_arn
             return self.wacls.get(wacl_arn)
         return None
 
